@@ -5,7 +5,7 @@ from pytezos.michelson.micheline import Schema, is_optional
 core_types = ['string', 'int', 'bool']
 domain_types = {
     'nat': 'int  /* Natural number */',
-    'unit': 'None /* Void */',
+    'unit': 'Unit || None /* Void */',
     'bytes': 'string  /* Hex string */ ||\n\tbytes  /* Python byte string */',
     'timestamp': 'int  /* Unix time in seconds */ ||\n\tstring  /* Formatted datetime `%Y-%m-%dT%H:%M:%SZ` */',
     'mutez': 'int  /* Amount in `utz` (10^-6) */ ||\n\tDecimal  /* Amount in `tz` */',
@@ -18,7 +18,14 @@ domain_types = {
 }
 
 
-def generate_docstring(schema: Schema, title, root='0'):
+def generate_docstring(schema: Schema, title, root='0') -> str:
+    """ Generate Michelson type (of arbitrary complexity) documentation in a more readable form.
+
+    :param schema: parameter/storage schema
+    :param title: documentation title
+    :param root: binary path to the root element (default is '0')
+    :returns: formatted docstring
+    """
     docstring = list()
     known_types = set()
 
