@@ -1,9 +1,12 @@
 import functools
 import operator
+from typing import List
 from pytezos.rpc.errors import RpcError
 
 
 class OperationResult:
+    """ Operation result representation + useful parsing helpers for operation group
+    """
 
     def __init__(self, **props):
         self.props = props
@@ -20,6 +23,12 @@ class OperationResult:
 
     @staticmethod
     def iter_contents(operation_group: dict):
+        """ Lazily iterate operation group contents including internal operations.
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        :returns: generator
+        """
         contents = operation_group.get('contents', [operation_group])
         for content in contents:
             yield {'internal': False, **content}
@@ -29,6 +38,12 @@ class OperationResult:
 
     @staticmethod
     def iter_results(operation_group: dict):
+        """ Lazily iterate operation results including internal operation results.
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        :returns: generator
+        """
         for content in OperationResult.iter_contents(operation_group):
             if content['internal'] and content.get('result'):
                 yield content['result']
@@ -36,22 +51,54 @@ class OperationResult:
                 yield content['metadata']['operation_result']
 
     @staticmethod
-    def consumed_gas(operation_group):
+    def consumed_gas(operation_group) -> int:
+        """ Get total consumed gas for an operation group (recursively).
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        """
         return sum(map(lambda x: int(x.get('consumed_gas', '0')),
                        OperationResult.iter_results(operation_group)))
 
     @staticmethod
-    def paid_storage_size_diff(operation_group):
+    def paid_storage_size_diff(operation_group) -> int:
+        """ Get total paid storage size diff for an operation group (recursively).
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        """
         return sum(map(lambda x: int(x.get('paid_storage_size_diff', '0')),
                        OperationResult.iter_results(operation_group)))
 
     @staticmethod
-    def is_applied(operation_group):
+    def burned(operation_group) -> int:
+        """ Get total burned (due to account allocations) for an operation group (recursively).
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        """
+        return sum(map(
+            lambda x: 257 if x.get('allocated_destination_contract') or x.get('originated_contracts') else 0,
+            OperationResult.iter_results(operation_group)))
+
+    @staticmethod
+    def is_applied(operation_group) -> bool:
+        """ Check if ALL operations in a group are applied.
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        """
         return all(map(lambda x: x['status'] == 'applied',
                        OperationResult.iter_results(operation_group)))
 
     @staticmethod
-    def errors(operation_group: dict):
+    def errors(operation_group: dict) -> list:
+        """ Collect errors from all operation results in a group.
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        :returns: list of errors [{"id": "", ...}]
+        """
         all_errors = (
             result.get("errors", []) if result["status"] != "applied" else []
             for result in OperationResult.iter_results(operation_group)
@@ -59,7 +106,13 @@ class OperationResult:
         return functools.reduce(operator.iconcat, all_errors, [])
 
     @staticmethod
-    def originated_contracts(operation_group: dict):
+    def originated_contracts(operation_group: dict) -> list:
+        """ Collect originated contract addresses from all operation results in a group.
+
+        :param operation_group: {"branch": "B...", "contents": [...], ...} \
+        OR a single content {"kind": "transaction", ...}
+        :returns: list of addresses ["tz12345...", ...]
+        """
         originated_contracts = list()
         for result in OperationResult.iter_results(operation_group):
             originated_contracts.extend(result.get('originated_contracts', []))
@@ -87,8 +140,14 @@ class OperationResult:
 
     @classmethod
     def from_operation_group(cls, operation_group: dict, **predicates):
+        """ Initialize with operation group contents.
+
+        :param operation_group: operation_group: {"branch": "B...", "contents": [...], ...} \
+        :param predicates: filter contents using predicates `field=value`
+        :rtype: List[OperationResult]
+        """
         if not cls.is_applied(operation_group):
-            raise RpcError.from_errors(cls.errors(operation_group)) from None
+            raise RpcError.from_errors(cls.errors(operation_group))
 
         def dispatch(content):
             if content['kind'] == 'transaction':
@@ -103,6 +162,11 @@ class OperationResult:
 
     @classmethod
     def from_origination(cls, content: dict):
+        """ Initialize with origination content.
+
+        :param content:
+        :rtype: OperationResult
+        """
         operation_result = cls.get_result(content)
         return cls(
             storage=content['script']['storage'],
@@ -111,6 +175,11 @@ class OperationResult:
 
     @classmethod
     def from_transaction(cls, content: dict):
+        """ Initialize with transaction content.
+
+        :param content:
+        :rtype: OperationResult
+        """
         operation_result = cls.get_result(content)
         return cls(
             parameters=content.get('parameters'),
